DetailTab

Enum DetailTab 

pub enum DetailTab {
    Tree,
    Interface,
    Connection,
}
Tab in the detail panel below the port table (selected process info).

These tabs only appear in the bottom split panel when ViewMode::Table is active and show_details is true.

Variants



Tree

Process tree view.



Interface

Network interface info.



Connection

Connection details.

Implementations

Source

impl DetailTab

pub const ALL: &[DetailTab]

All tabs in display order.

pub fn index(self) -> usize

Position of this tab in Self::ALL (0-based).

pub fn next(self) -> Self

Cycle to the next tab (wraps around).

pub fn prev(self) -> Self

Cycle to the previous tab (wraps around).

pub fn key_label(self) -> String

One-based label used for the tab bar and key dispatch, e.g. "1".