pub enum DetailTab {
Tree,
Interface,
Connection,
}Expand description
Tab in the detail panel below the port table (selected process info).
These tabs only appear in the bottom split panel when ViewMode::Table
is active and show_details is true.
Variants
Implementations